from typing import Dict
from ledgerx.client import Client
from ledgerx.util import gen_headers


class TraderBlotter:
    @staticmethod
    def next(next_url: str):
        client = Client()
        headers = gen_headers()
        res = client.get(next_url, headers)
        return res.json()

    @staticmethod
    def list(params: Dict, next: str = ""):
        client = Client()
        url = "https://api.ledgerx.com/trading/trades/global"
        default_params = dict(
            status_type=201, limit=50, min_size=100, mine=False, asset="CBTC"
        )
        headers = gen_headers()
        res = client.get(url, headers, params)
        data = res.json()
        return data



import requests
from typing import Dict


class Client:
    def __init__(self):
        pass

    def get(self, url, headers, params={}):
        return requests.get(url, headers=headers, params=params)

    def post(self, url, headers, data):
        return requests.post(url, headers=headers, json=data)



from typing import Dict


def gen_headers() -> Dict:
    return {
        "Referrer-Policy": "strict-origin-when-cross-origin",
        "accept": "*/*",
        "accept-encoding": "gzip, deflate, br",
        "accept-language": "en-US,en;q=0.9",
        "origin": "https://omni.ledgerx.com",
        "refer": "https://omni.ledgerx.com/",
        "sec-fetch-dest": "empty",
        "sec-fetch-mode": "cors",
        "sec-fetch-site": "same-site",
        "user-agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/88.0.4324.96 Safari/537.36",
    }
